<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Interfaces\Admin\CategoryRepositoryInterface;
use App\Models\Category;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;

class CategoryController extends Controller
{
    protected $categoryRepository;
    public function __construct(CategoryRepositoryInterface $categoryRepository)
    {
        $this->categoryRepository = $categoryRepository;
    }

    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $categories = $this->categoryRepository->index();
        return view('admin.category.index',compact('categories'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        //
    }

    public function store(Request $request)
    {
        $this->validate($request,[
            'ar_name' => 'required|unique:categories',
            'en_name' => 'required|unique:categories',
            'image' => 'required'
        ]);
        $id = (int)$request->parent_id;
        $this->categoryRepository->storeSub($request);
        return redirect(route('sub_cats',$id))->with('success','Sub category added successfully');
    }

    public function storeThird(Request $request)
    {
        $this->validate($request,[
            'ar_name' => 'required|unique:categories',
            'en_name' => 'required|unique:categories',
            'price' => 'required|numeric',
            'description' => 'required',
            'image' => 'required'
        ],[
            'ar_name.required' => 'Arabic text is required',
            'ar_name.unique' => 'Arabic text must be unique',
            'en_name.required' => 'English text is required',
            'en_name.unique' => 'English text must be unique',
            'price.required' => 'Price text is required',
            'price.numeric' => 'Price must be number',
            'description.required' => 'Description is required',
            'image.required' => 'Image is required',
        ]);
        $id = (int)$request->parent_id;
        $this->categoryRepository->storeThird($request);
        return redirect(route('third_cats',$id))->with('success','Third Category added successfully');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function showSubCat($id)
    {
        $categories = $this->categoryRepository->getSubCat($id);
        return view('admin.category.show',compact('categories','id'));
    }

    public function showThirdCat($thirdId)
    {
        $categories = $this->categoryRepository->getThirdCat($thirdId);
        return view('admin.category.show',compact('categories','thirdId'));
    }

    public function editCat(Request $request)
    {
        $this->validate($request,[
            'ar_name' => 'required',
            'en_name' => 'required',
            'price' => 'sometimes|numeric',
            'description' => 'sometimes',
            'image' => 'sometimes'
        ],[
            'ar_name.required' => 'Arabic text is required',
            'ar_name.unique' => 'Arabic text must be unique',
            'en_name.required' => 'English text is required',
            'en_name.unique' => 'English text must be unique',
            'price.numeric' => 'Price must be number',
        ]);
        if($request->parent_id)
        {
            $id = (int)$request->parent_id;
            $this->categoryRepository->editCat($request);
            return redirect(route('sub_cats',$id))->with('success','Category updated successfully');
        }elseif($request->parent_third_id){
            $id = (int)$request->parent_third_id;
            $this->categoryRepository->editCat($request);
            return redirect(route('third_cats',$id))->with('success','Category updated successfully');
        }
    }

    public function get_sub_category($parent)
    {
        $sub_cats = Category::where('parent_id',$parent)->get();
        return response()->json($sub_cats);
    }


    public function edit($id)
    {
        //
    }

    public function update(Request $request, $id)
    {
        //
    }

    public function destroy($id)
    {
        //
    }
}
