<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Interface_directory\Admin\DriverRepositoryInterface;
use App\Models\Car;
use App\Models\Driver;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;

class DriverController extends Controller
{
    protected $driverRepository;
    public function __construct(DriverRepositoryInterface $driverRepository)
    {
        $this->driverRepository = $driverRepository;
    }

    public function index()
    {
        $all = $this->driverRepository->driver();
        $drivers = $all['drivers'];
        $countries = $all['countries'];
        $cars = $all['cars'];

        return view('admin.driver.index',compact('drivers','countries','cars'));
    }

    public function create()
    {
        //
    }

    public function store(Request $request)
    {
        $this->validate($request,[
            'name' => 'required',
            'email' => 'required|email',
            'phone' => 'required|numeric',
            'password' => 'required|min:6',
            'car_id' => 'required',
            'country_id' => 'required|exists:countries,id',
            'image' => 'required',
        ]);
        $driver = $this->driverRepository->storeDriver($request);

        if($driver == 'email_exist')
            return redirect(route('driver.index'))->with('error','Email already exists');
        elseif($driver == 'phone_exist')
            return redirect(route('driver.index'))->with('error','Phone already exists');
        else
            return redirect(route('driver.index'))->with('success','Driver added successfully');
    }

    public function show($id)
    {
        $driver = Driver::whereId($id)->first();
        return view('admin.driver.show',compact('driver'));
    }

    public function changeStatus(Request $request)
    {
        $this->validate($request,[
            'driver_id' => 'required|exists:drivers,id'
        ]);

        $driver = $this->driverRepository->changStatus($request->driver_id);
        if($driver == 'suspend')
            return back()->with('success','Driver suspended successfully');
        else
            return back()->with('success','Driver activated successfully');
    }

    public function activeContract(Request $request)
    {
        $this->validate($request,[
            'driver_id' => 'required|exists:drivers,id'
        ]);

        $this->driverRepository->activeContract($request->driver_id);
        return back()->with('success','User activated successfully');
    }

    public function edit($id)
    {
        $driver = Driver::whereId($id)->first();
        $cars = Car::all();
        return view('admin.driver.single',compact('driver','cars'));
    }

    public function update(Request $request)
    {
        $this->validate($request,
            [
                'driver_id' => 'required|exists:drivers,id',
                'car_id' => 'sometimes',
                'name' => 'required',
                'email' => 'required|unique:drivers,email,'.$request->driver_id,
                'phone' => 'required|unique:drivers,phone,'.$request->driver_id,
                'image' => 'sometimes|image',
            ],
            [
                'name.required' => 'Name is required',
                'email.required' => 'Email is required',
                'phone.required' => 'Phone is required',
                'image.image' => 'Image is invalid',
            ]
        );


        $email_check = Driver::where('id','!=',$request->driver_id)->where('email', $request->email)->first();
        $phone_check = Driver::where('id','!=',$request->driver_id)->where('phone', $request->phone)->first();

        if($email_check) return back()->with('error', 'Sorry,email already exists,please change to another one');
        if($phone_check) return back()->with('error', 'Sorry,phone already exists,please change to another one');

        $this->driverRepository->updateDriver($request);
        return back()->with('success', 'Updated Successfully');

    }

    public function destroy($id)
    {
        //
    }

    public function search(Request $request)
    {
        $drivers = $this->driverRepository->search($request);
        return view('admin.driver.index',compact('drivers'));
    }
}
