<?php

namespace App\Http\Controllers\Api\App;

use App\Http\Controllers\Interface_directory\Api\App\AppRepositoryInterface;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Validator;

class AppController extends Controller
{
    protected $appRepository;
    public function __construct(AppRepositoryInterface $appRepository)
    {
        $this->appRepository = $appRepository;
    }

    public function sendMessage(Request $request)
    {
        $validator  = Validator::make($request->all(),[
            'user_id' => 'required|exists:users,id',
            'driver_id' => 'required|exists:drivers,id',
            'body' => 'required',
            'sent' => 'required|in:user,driver',
        ]);

        if($validator->fails())
        {
            return response()->json(['status'=> 401, 'msg'=> $validator->messages()]);
        }

        $message = $this->appRepository->sendMessage($request,$request->header('lang'));
        return response()->json(msgdata($request,success(),'success',$message));
    }

    public function getChat(Request $request)
    {
        $validator  = Validator::make($request->all(),[
            'user_id' => 'required|exists:users,id',
            'driver_id' => 'required|exists:drivers,id',
        ]);

        if($validator->fails())
        {
            return response()->json(['status'=> 401, 'msg'=> $validator->messages()]);
        }

        $message = $this->appRepository->getChat($request);
        return response()->json(msgdata($request,success(),'success',$message));
    }

    public function rate(Request $request)
    {
        $validator  = Validator::make($request->all(),[
            'trip_id' => 'required|exists:trips,id',
            'rate' => 'required|numeric',
            'type' => 'required|in:user,driver'
        ]);

        if($validator->fails())
        {
            return response()->json(['status'=> 401, 'msg'=> $validator->messages()]);
        }

        $rate = $this->appRepository->rate($request);

        if($rate == false)
            return response()->json(msg($request,failed(),'already_rate'));
        else
            return response()->json(msg($request,success(),'rate'));
    }

    public function getDetailTrip(Request $request)
    {
        $validator = Validator::make($request->all(),[
            'trip_id' => 'required|exists:trips,id',
        ]);

        if($validator->fails())
            return response()->json(['status'=> 401, 'msg'=> $validator->messages()]);

        $trip = $this->appRepository->getDetailTrip($request);
        return response()->json(msgdata($request,success(),'success',$trip));
    }
}
