<?php
/**
 * Created by PhpStorm.
 * User: Al Mohands
 * Date: 04/09/2019
 * Time: 03:38 م
 */

namespace App\Http\Controllers\Eloquent\Api\Driver;


use App\Http\Controllers\Interface_directory\Api\Driver\AuthRepositoryInterface;
use App\Models\Driver;
use App\Models\DriverCar;
use App\Models\DriverCredit;
use App\Models\DriverProfile;
use App\Models\Verification;
use Carbon\Carbon;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Str;

class AuthRepository implements AuthRepositoryInterface
{
    public function checkJWT($jwt)
    {
        return Driver::whereJwt($jwt)->select('id')->first();
    }

    public function firstRegister($input)
    {
        $phone = Driver::where('phone', $input->phone)->select('id')->first();
        if($phone) return 'phone_exist';

        $email = Driver::where('email', $input->email)->select('id')->first();
        if($email) return 'email_exist';

        $driver = Driver::create([
           'jwt' => Str::random(25),
           'name' => $input->name,
           'phone' => $input->phone,
           'email' => $input->email,
           'password' => Hash::make($input->password),
           'finish' => '0'
        ]);

        DriverProfile::create([
            'driver_id' => $driver->id
        ]);

        DriverCredit::create([
            'driver_id' => $driver->id
        ]);

        $this->sendSms($input->phone,'activate');
    }

    public function secondRegister($input)
    {
        $driver = Driver::where('id',$input->driver_id)->where('finished',0)->select('id','active','jwt','name','email','phone','image')->first();

        if($driver)
        {
            DriverCar::create([
                'driver_id' => $input->driver_id,
                'model' => $input->model,
                'color' => $input->color,
                'plat_number' => $input->plat_number
            ]);

            $driver->update(['finished',1]);

            return $driver;
        }
    }

    public function sendSms($phone,$type)
    {
        $driver = Driver::where('phone', $phone)->select('id')->first();

        if($driver)
        {
            Verification::create([
                'role'=>'driver',
                'type' => $type,
                'phone' => $phone,
                'code' => generateActivationCode(),
                'expire_at' => Carbon::now()->addHour()->toDateTimeString()
            ]);
        }else return 'phone_not_exist';
    }

    public function codeCheck($input)
    {
        $verify = Verification::where('role','driver')->whereCode($input->code)->first();
        if($verify)
        {
            if($verify->status == 0)
            {
                if(Carbon::now()->format('Y-m-d H') > Carbon::parse($verify->expire_at)->format('Y-m-d H'))
                    return 'expire';
                else
                    if($verify->type == 'activate')
                    {
                        $driver = Driver::where('phone',$verify->phone)->select()->select('id','active','jwt','name','email','phone','image')->first();
                        $driver->active = 1;
                        $driver->save();
                        $verify->update(['status' => 1]);
                        return $driver;
                    }
                    elseif($verify->type == 'reset')
                    {
                        $driver = Driver::where('phone',$verify->phone)->select()->select('id','active','jwt','name','email','phone','image')->first();
                        $verify->update(['status' => 1]);
                        return $driver;
                    }
            }
            else return 'activated_before';
        }
        else return 'invalid_code';
    }

    public function login($input)
    {
        $driver = Driver::where('phone',$input->phone)->first();
        if($driver)
        {
            $check = Hash::check($input->password,$driver->password);
            if($check)
            {
                if($driver->active == 0) return 'not_active';
                elseif($driver->accept == 0) return 'waiting_admin';
                elseif($driver->finished) return 'not_finished';

                $driver->update([
                    'token' => $input->token,
                    'jwt' => Str::random(25)
                ]);

                unset($driver->deleted_at,$driver->created_at,$driver->updated_at,$driver->count);

                return $driver;
            }
            else return false;
        }
        else return 'not_exist';
    }

    public function forgetPassword($input)
    {
        Driver::where('id',$input->driver_id)->update(['password' => Hash::make($input->password)]);
    }
}
