<?php
/**
 * Created by PhpStorm.
 * User: Al Mohands
 * Date: 09/09/2019
 * Time: 02:24 م
 */

namespace App\Http\Controllers\Eloquent\Api\Driver;

use App\Models\Car;
use App\Models\Driver;
use App\Models\DriverCredit;
use App\Models\DriverNotify;
use App\Models\Message;
use App\Models\Notify;
use App\Models\ServiceCar;
use App\Models\Trip;
use App\Models\TripActiveRequest;
use App\Models\TripDistance;
use App\Models\TripPath;
use App\Models\TripStatus;
use App\Models\User;
use App\Models\UserNotify;
use Carbon\Carbon;

use App\Http\Controllers\Interface_directory\Api\Driver\TripRepositoryInterface;

class TripRepository implements TripRepositoryInterface
{
    public function tripActiveRequest($trip_id,$driver_id)
    {
        return TripActiveRequest::where('trip_id',$trip_id)->where('driver_id', $driver_id)
            ->where('driver_status',0)->where('time_out','>=',Carbon::now())->first();
    }

    public function acceptTrip($input)
    {
        $active_trip = $this->tripActiveRequest($input->trip_id,$input->driver_id);

        if($active_trip)
        {
            $user_id = Trip::where('id', $input->trip_id)->select('user_id')->first()->user_id;

            $active_trip->update(['driver_status' => 1]);

            Trip::where('id',$input->trip_id)->update(['driver_id'=>$input->driver_id]);
            Driver::where('id',$input->driver_id)->update(['status' => 1]);

            TripStatus::create([
                'trip_id' => $input->trip_id,
                'status_id' => 5
            ]);

            $ar_message = 'قام السائق بالموافقة و الرد علي طلبك';
            $en_message = 'Driver accept and responded to your request ';

            UserNotify::create([
                'user_id' => $user_id,
                'trip_id' => $input->trip_id,
                'en' => ['name' => $en_message],
                'ar' => ['name' => $ar_message]
            ]);

            $user_token = User::where('id',$user_id)->pluck('token');

            Notify::send($user_token,'accept','accept','',$input->trip_id,$input->driver_id);

            $trip_path = Trip::where('id',$input->trip_id)->select('id','user_id')->with(['tripPath','user'])->first();
            return $trip_path;
        }
        else return false;
    }

    public function cancelTrip($input,$lang)
    {
        $active_trip = $this->tripActiveRequest($input->trip_id,$input->driver_id);

        if($active_trip)
        {
            $active_trip->update(['driver_status' => 2]);

            TripStatus::create([
                'trip_id' => $input->trip_id,
                'status_id' => 6
            ]);

            $driver = Driver::where('id',$input->driver_id)->select('id','count')->first();
            $driver_count = json_decode($driver->count,true);

            if($driver->count == null)
            {
                $driver->update([
                    'count' => collect(['2' => 1,'3' => 0])
                ]);

            }else{
                $driver->update([
                    'count' => collect(['2' => $driver_count['2']+1,'3' => 0])
                ]);

            }

            if($driver_count['2'] >= 3)
            {
                $driver_credit = DriverCredit::where('driver_id',$input->driver_id)->first();
                $service_fees = ServiceCar::where('country_id',$input->country_id)->select('id','cancel_before_fees')->first();
                $fees = 0;
                $fees+=$service_fees->cancel_before_fees;

                if($driver_credit)
                {
                    $driver_credit->update([
                        'admin_credit' => $fees
                    ]);
                }
                else{
                    DriverCredit::create([
                        'driver_id' => $input->driver_id,
                        'admin_credit' => $fees,
                    ]);
                }
            }
            $user_id = Trip::where('id', $input->trip_id)->select('user_id')->first()->user_id;

            $ar_message = 'قام السائق بالغاء الطلب.';
            $en_message = 'Driver cancel the order';

            UserNotify::create([
                'user_id' => $user_id,
                'trip_id' => $input->trip_id,
                'en' => ['name' => $en_message],
                'ar' => ['name' => $ar_message]
            ]);

            $user_token = User::where('id',$user_id)->pluck('token');

            Notify::send($user_token,'reject','reject','',$input->trip_id,$input->driver_id);

            $active_trips = TripActiveRequest::where('trip_id',$input->trip_id)->where('driver_status',0)->get();

            if($active_trips)
            {
                foreach ($active_trips as $active_trip)
                {
                    $car_id = Trip::where('id',$active_trip->trip_id)->select('car_id')->first();
                    $trip_path = TripPath::where('trip_id',$active_trip->trip_id)->where('type','pick_up')->first();

                    $filter_trip = TripPath::filterbylatlng($trip_path->lat,$trip_path->lng,50,'drivers',$car_id);
                    if (count($filter_trip) > 0) {
                        $ar_message = 'لديك طلب رحلة جديد,الرجاء الإستجابة';
                        $en_message = 'You have a new trip request,please respond';

                        foreach ($filter_trip as $filter) {
                            DriverNotify::create([
                                'driver_id' => $filter->id,
                                'trip_id' => $active_trip->trip_id,
                                'en' => ['name' => $en_message],
                                'ar' => ['name' => $ar_message]
                            ]);

                            $driver_token = Driver::where('id', $filter->id)->pluck('token');
                            Notify::send($driver_token, 'trip', $lang == 'ar' ? $ar_message : $en_message, '', $active_trip->trip_id, $filter->id);
                        }
                    }
                }
            }

            return true;
        }
        else return false;
    }

    public function cancelAfterAccept($input,$lang)
    {
        $accept_trip = TripActiveRequest::where('trip_id',$input->trip_id)->where('driver_id', $input->driver_id)
            ->where('driver_status',1)->first();

        if($accept_trip)
        {
            $accept_trip->update(['driver_status' => 3]);
            Driver::where('id',$input->driver_id)->update(['status' => 0]);

            TripStatus::create([
                'trip_id' => $input->trip_id,
                'status_id' => 6
            ]);

            $driver = Driver::where('id',$input->driver_id)->select('id','count')->first();
            $driver_count = json_decode($driver->count,true);

            $driver->update([
                'count' => collect(['2'=>$driver_count['2'],'3' => $driver_count['3']+1])
            ]);

            if($driver_count['3'] >= 3)
            {
                $driver_credit = DriverCredit::where('driver_id',$input->driver_id)->first();
                $service_fees = ServiceCar::where('country_id',$input->country_id)->select('id','cancel_after_fees')->first();
                $fees = 0;
                $fees+=$service_fees->cancel_before_fees;

                if($driver_credit)
                {
                    $driver_credit->update([
                        'admin_credit' => $fees
                    ]);
                }
            }
            $user_id = Trip::where('id', $input->trip_id)->select('user_id')->first()->user_id;

            $ar_message = 'قام السائق بالغاء الطلب.';
            $en_message = 'Driver cancel the order';

            UserNotify::create([
                'user_id' => $user_id,
                'trip_id' => $input->trip_id,
                'en' => ['name' => $en_message],
                'ar' => ['name' => $ar_message]
            ]);

            $user_token = User::where('id',$user_id)->pluck('token');

            Notify::send($user_token,'reject','reject','',$input->trip_id,$input->driver_id);

            $active_trips = TripActiveRequest::where('trip_id',$input->trip_id)->where('driver_status',0)->get();

            if($active_trips)
            {
                foreach ($active_trips as $active_trip)
                {
                    $car_id = Trip::where('id',$active_trip->trip_id)->select('car_id')->first();
                    $trip_path = TripPath::where('trip_id',$active_trip->trip_id)->where('type','pick_up')->first();

                    $filter_trip = TripPath::filterbylatlng($trip_path->lat,$trip_path->lng,50,'drivers',$car_id);
                    if (count($filter_trip) > 0) {
                        $ar_message = 'لديك طلب رحلة جديد,الرجاء الإستجابة';
                        $en_message = 'You have a new trip request,please respond';

                        foreach ($filter_trip as $filter) {
                            DriverNotify::create([
                                'driver_id' => $filter->id,
                                'trip_id' => $active_trip->trip_id,
                                'en' => ['name' => $en_message],
                                'ar' => ['name' => $ar_message]
                            ]);

                            $driver_token = Driver::where('id', $filter->id)->pluck('token');
                            Notify::send($driver_token, 'trip', $lang == 'ar' ? $ar_message : $en_message, '', $active_trip->trip_id, $filter->id);
                        }
                    }
                }
            }

            return true;
        }
        else return false;
    }

    public function arrive($input,$lang)
    {
        $active_trip = TripActiveRequest::where('trip_id',$input->trip_id)->where('driver_id', $input->driver_id)->where('driver_status',1)->first();
        if($active_trip)
        {
            $user_id = Trip::where('id', $input->trip_id)->select('user_id')->first()->user_id;

            $active_trip->update(['arrive' => 1]);

            TripStatus::create([
                'trip_id' => $input->trip_id,
                'status_id' => 7
            ]);
            $ar_message = 'قام السائق بالوصول.';
            $en_message = 'Driver arrive.';

            UserNotify::create([
                'user_id' => $user_id,
                'trip_id' => $input->trip_id,
                'en' => ['name' => $en_message],
                'ar' => ['name' => $ar_message]
            ]);

            $user_token = User::where('id',$user_id)->pluck('token');
            Notify::send($user_token, 'arrive', $lang == 'ar' ? $ar_message : $en_message, '', $active_trip->trip_id, $input->driver_id);
            return true;
        }else return false;
    }

    public function updateAvailability($input)
    {
        $driver = Driver::where('id',$input->driver_id)->first();
        $driver->available = $input->available;
        $driver->lat = $input->lat;
        $driver->lng = $input->lng;
        $driver->save();
    }

    public function tripHistory($input)
    {
        $trips = Trip::where('driver_id',$input->driver_id)->select('id','rate','order_action','total','created_at')->get();
        foreach ($trips as $trip)
        {
            $trip['rate'] = $trip->rate['driver'];
            $pick_up = TripPath::where('trip_id',$trip->id)->where('type','pick_up')->select('address')->first();
            $where_to = TripPath::where('trip_id',$trip->id)->where('type','where_to')->select('address')->first();
            $end_trip = TripPath::where('trip_id',$trip->id)->where('type','end_trip')->select('address')->first();
            if($pick_up)
            {
                $trip['pickup_address'] = $pick_up->address;
                if($trip->type == 'urgent')
                    $trip['endtrip_address'] = $end_trip->address;
                else
                    $trip['endtrip_address'] = $where_to->address;
            }
        }
        return $trips;
    }

    public function calculateTrip($input)
    {
        $locations = $input->locations;

        $total_distance = 0;
        $waiting_time=0;
        if (count($locations) >= 4 )
        {
            for ($i = 0, $j = 1; $j < count($locations)-2; $i+=2, $j+=2) {
                $distanceKM =  getDistanceLatLng($locations[$i],$locations[$j],$locations[$i+2],$locations[$j+2]);
                $total_distance += $distanceKM;
                $distanceMeter = $distanceKM * 1000;
                if($distanceMeter < 20)
                    $waiting_time += 5;
            }
        }

        //store in DB

        $trip_distance = TripDistance::where('trip_id',$input->trip_id)->first();
        if($trip_distance)
        {
            $trip_distance->distance += $total_distance;
            $trip_distance->waiting_time += $waiting_time;
            $trip_distance->save();
        }else{
            TripDistance::create([
                'trip_id' => $input->trip_id,
                'distance' => $total_distance,
                'waiting_time' => $waiting_time
            ]);
        }
    }

    public function endTrip($input,$lang)
    {
       $service = ServiceCar::where('country_id',$input->country_id)->first();

       if($service)
       {
           $trip = Trip::where('id',$input->trip_id)->first();
           $car_price = Car::where('id',$trip->car_id)->first();

           $trip_distance = TripDistance::where('trip_id',$input->trip_id)->first();
           if($trip_distance)
           {
               $total = $service->start + ($trip_distance->distance * $car_price->price) + ($trip_distance->waiting_time * $service->wait) + $service->service_fees;
           }else{
               $total = $service->minimum_fare;
           }

           $trip_total = number_format($total,2);

           Trip::where('id',$input->trip_id)->update(['order_action' => 1,'total' => $trip_total]);

           Driver::where('id',$trip->driver_id)->update(['status' => 0]);

           TripPath::create([
               'trip_id' => $input->trip_id,
               'type' => 'end_trip',
               'address' => $input->address,
               'lat' => $input->lat,
               'lng' => $input->lng
           ]);

           TripStatus::create([
              'trip_id' => $input->trip_id,
               'status_id' => 12
           ]);

           $ar_message = 'تم الانتهاء من الرحلة.';
           $en_message = 'Trip finished.';

           UserNotify::create([
               'user_id' => $trip->user_id,
               'trip_id' => $input->trip_id,
               'en' => ['name' => $en_message],
               'ar' => ['name' => $ar_message]
           ]);

           $driver_token = User::where('id', $trip->user_id)->pluck('token');
           Notify::send($driver_token, 'rate', $lang == 'ar' ? $ar_message : $en_message, '', $input->trip_id, $trip->driver_id,'',$trip_total);

           return $trip_total;
       }
    }
}
