<?php
/**
 * Created by PhpStorm.
 * User: Al Mohands
 * Date: 29/08/2019
 * Time: 09:27 ص
 */

namespace App\Http\Controllers\Eloquent\Api\User;


use App\Http\Controllers\Interface_directory\Api\User\AuthRepositoryInterface;
use App\Models\User;
use App\Models\Verification;
use Carbon\Carbon;
use Illuminate\Support\Str;

class AuthRepository implements AuthRepositoryInterface
{
    public function checkByPhone($phone)
    {
        return User::where('phone', $phone)->select('id','jwt','active','name','phone','email','payment_type','rate','wallet_amount','image','device_token')->first();
    }

    public function checkJWT($jwt)
    {
        return User::whereJwt($jwt)->select('id')->first();
    }

    public function loginRegister($input)
    {
        $user = $this->checkByPhone($input->phone);

        if($user)
        {
            $user->update([
                'jwt' => Str::random(25),
            ]);
            $this->sendSms($input->phone);
            return $user;
        }
        else
        {
            $user = User::create([
                'jwt' => Str::random(25),
                'phone' => $input->phone,
                'token'=>$input->token
            ]);

            $this->sendSms($input->phone);
            return $user;
        }
    }

    public function sendSms($phone)
    {
        $user = $this->checkByPhone($phone);

        if($user)
        {
            Verification::updateOrcreate(
                [
                'role'=>'user',
                'type' => 'activate',
                'phone' => $phone,
                ],
                [
                'code' => generateActivationCode(),
                'status' => 0,
                'expire_at' => Carbon::now()->addHour()->toDateTimeString()
                ]
            );
        }else return 'phone_not_exist';
    }

    public function codeCheck($input)
    {
        $verify = Verification::where('role','user')->whereCode($input->check_code)->first();
        if($verify)
        {
            if($verify->status == 0)
            {
                if (Carbon::now()->format('Y-m-d H') > Carbon::parse($verify->expire_at)->format('Y-m-d H'))
                    return 'expire';
                else
                    if ($verify->type == 'activate') {

                        $user = $this->checkByPhone($verify->phone);
                        $user->update([
                            'active' => 1,
                            'token' => $input->token,
                            'device_token' => $input->device_token
                        ]);
                        $verify->update(['status' => 1]);
                        return $user;

                    } elseif ($verify->type == 'reset') {
                        $verify->update(['status', 1]);
                        $user = $this->checkByPhone($verify->phone);
                        return $user;
                    }
            }
            else return 'activated_before';
        }
        else return 'invalid_code';
    }
}
