<?php
/**
 * Created by PhpStorm.
 * User: Al Mohands
 * Date: 09/09/2019
 * Time: 04:11 م
 */

namespace App\Http\Controllers\Eloquent\Api\User;


use App\Http\Controllers\Interface_directory\Api\User\UserRepositoryInterface;
use App\Models\Promo;
use App\Models\PromoUsed;
use App\Models\User;
use App\Models\UserNotify;
use App\Models\Verification;
use Carbon\Carbon;

class UserRepository implements UserRepositoryInterface
{
    public function checkByPhone($phone)
    {
        return User::where('phone', $phone)->select('id','jwt','active','name','phone','email','payment_type','rate','wallet_amount','image')->first();
    }

    public function updateProfile($input)
    {
        $user = User::where('id',$input->user_id)->select('id','name','phone','email')->first();

        if($input->name)
        {
            $user->name = $input->name;
        }
        elseif($input->email)
        {
            $email = User::where('id','!=',$input->user_id)->where('email',$input->email)->first();
            if($email) return 'email_exist';
            else
            {
                $user->email = $input->email;
            }
        }
        elseif($input->phone)
        {
            $phone = User::where('id','!=',$input->user_id)->where('phone',$input->phone)->first();
            if($phone) return 'phone_exist';
            else
            {
                $user->phone = $input->phone;
                $this->sendSms($input->phone);
            }
        }
        elseif ($input->image)
        {
            $user->image = $input->image;
        }elseif($input->promo_code)
        {
            $promo = Promo::where('code', $input->promo_code)->where('start_date','<=',Carbon::now())->where('end_data','>=',Carbon::now())->first();
            if($promo)
            {
                $promo_used = PromoUsed::where('user_id',$input->user_id)->where('promo_id',$promo->id)->where('status',1)->first();
                if($promo_used)
                {
                    return 'promo_used';
                }else{
                    PromoUsed::create([
                        'user_id' => $input->user_id,
                        'promo_id' => $input->promo_id,
                        'status' => 1,
                    ]);
                }
            }else{
                return 'invalid_promo';
            }
        }
        $user->save();

        return $user;
    }

    public function updatePaymentType($input)
    {
        $user = User::where('id',$input->user_id)->select('id','payment_type')->first();
        $user->update(['payment_type' => $input->payment_type]);
        return $user;
    }

    public function showNotify($input,$lang)
    {
        $user = UserNotify::where('user_id',$input->user_id)->with(['notify'=>function($query)use($lang){
            $query->where('locale',$lang);
        }])->select('id','created_at')->get();

        return $user;
    }

    public function sendSms($phone)
    {
        $user = $this->checkByPhone($phone);

        if($user)
        {
            Verification::create([
                'role'=>'user',
                'type' => 'activate',
                'phone' => $phone,
                'code' => generateActivationCode(),
                'expire_at' => Carbon::now()->addHour()->toDateTimeString()
            ]);
        }
    }

    public function addPromo($input)
    {
        $promo = Promo::where('code',$input->code)->where('limit','>',0)->where('start_date','<=',Carbon::now())->where('end_date','>=',Carbon::now())->first();
        if($promo)
        {
            $promo_used = PromoUsed::where('user_id',$input->user_id)->where('promo_id',$promo->id)->first();
            if($promo_used)
            {
                return 'promo_used';
            }else{
                PromoUsed::create([
                    'user_id' => $input->user_id,
                    'promo_id' => $promo->id,
                    'status' => 1
                ]);

                if($promo->limit > 0)
                {
                    $promo->update(['limit'=> $promo->limit-1]);
                }

                return $promo;
            }
        }
        else{
            return 'invalid_promo';
        }
    }

}
