<?php

/*
|--------------------------------------------------------------------------
| Web Routes
|--------------------------------------------------------------------------
|
| Here is where you can register web routes for your application. These
| routes are loaded by the RouteServiceProvider within a group which
| contains the "web" middleware group. Now create something great!
|
*/
use \App\Http\Middleware\IsAdmin;

Route::get('/', function () {
    return view('welcome');
});

Route::group(['prefix' => '/admin'], function (){
    Route::get('/login', 'Admin\AuthController@login_view');
    Route::post('/login', 'Admin\AuthController@login')->name('login');
    Route::get('/logout', 'Admin\AuthController@logout')->name('logout');

    Route::group(['middleware' => 'auth:admin'], function (){

        Route::get('/dashboard', 'Admin\HomeController@dashboard')->name('dashboard');

        Route::group(['middleware' => ['permission:View user']], function () {
            Route::get('/users/type/{type}', 'Admin\UserController@index')->name('users_view');
            Route::group(['middleware' => ['permission:Add user']], function () {
                Route::resource('/users', 'Admin\UserController');
            });
            Route::group(['middleware' => ['permission:Active user']], function () {
                Route::post('/users/change_status', 'Admin\UserController@changeStatus')->name('userChangeStatus');
            });
            Route::get('/user/search', 'Admin\UserController@search');
        });

        Route::group(['middleware' => ['permission:View driver']], function () {
            Route::group(['middleware' => ['permission:Add driver']], function () {
                Route::resource('/driver', 'Admin\DriverController');
            });
            Route::group(['middleware' => ['permission:Active driver']], function () {
                Route::post('/accept', 'Admin\DriverController@activeContract')->name('driver_accept');
            });
            Route::group(['middleware' => ['permission:Edit driver']], function () {
                Route::post('/driver/update', 'Admin\DriverController@update')->name('updateDriver');
            });
            Route::group(['middleware' => ['permission:Active driver|Suspend driver']], function () {
                Route::post('/change_status', 'Admin\DriverController@changeStatus')->name('driver_change_status');
            });
            Route::get('/driver/search', 'Admin\DriverController@search');
        });

        Route::group(['middleware' => ['permission:View service']], function () {
            Route::get('/servicecar', 'Admin\ServiceCarsController@index')->name('service.car');

            Route::group(['middleware' => ['permission:Add service']], function () {
                Route::post('/servicecar/store', 'Admin\ServiceCarsController@store')->name('service.car.store');
            });
            Route::group(['middleware' => ['permission:Edit service']], function () {
                Route::get('/servicecar/{service_id}', 'Admin\ServiceCarsController@edit')->name('service.car.edit');
                Route::patch('/servicecar/edit/{service_id}', 'Admin\ServiceCarsController@update')->name('service.car.update');
            });
        });

        Route::group(['middleware' => ['permission:View cars']], function () {
            Route::get('/cars', 'Admin\CarsController@index')->name('cars');

            Route::group(['middleware' => ['permission:Add cars']], function () {
                Route::post('/cars/store', 'Admin\CarsController@store')->name('cars.store');
            });
            Route::group(['middleware' => ['permission:Edit cars']], function () {
                Route::get('/cars/{car_id}', 'Admin\CarsController@edit')->name('cars.edit');
                Route::patch('/cars/edit/{car_id}', 'Admin\CarsController@update')->name('cars.update');
            });
        });

        Route::group(['middleware' => ['permission:View country']], function () {
            Route::get('/country', 'Admin\CountryController@index')->name('countries');

            Route::group(['middleware' => ['permission:Add country']], function () {
                Route::post('/country/store', 'Admin\CountryController@store')->name('countries.store');
            });

            Route::group(['middleware' => ['permission:Edit country']], function () {
                Route::get('/country/{country_id}', 'Admin\CountryController@edit')->name('countries.edit');
                Route::patch('/country/edit/{country_id}', 'Admin\CountryController@update')->name('countries.update');
            });
        });

        Route::group(['middleware' => ['permission:View promo']], function () {
            Route::get('/promo', 'Admin\PromoController@index')->name('promos');

            Route::group(['middleware' => ['permission:Add promo']], function () {
                Route::post('/promo/store', 'Admin\PromoController@store')->name('promos.store');
            });
            Route::group(['middleware' => ['permission:Edit promo']], function () {
                Route::get('/promo/{promo_id}', 'Admin\PromoController@edit')->name('promos.edit');
                Route::patch('/promo/edit/{promo_id}', 'Admin\PromoController@update')->name('promos.update');
            });
        });

        Route::group(['middleware' => ['permission:View admins']], function () {
            Route::resource('admins', 'Admin\AdminController');
        });

        Route::group(['middleware' => ['permission:View trips']], function () {
            Route::get('/trips', 'Admin\TripController@index')->name('trips');
            Route::get('/trips/{id}/view', 'Admin\TripController@view')->name('trips_view');
            Route::get('/trips/export', 'Admin\TripController@trips_export');
            Route::get('/trips/search', 'Admin\TripController@search');
        });

        Route::group(['prefix' => '/settings'], function(){

            Route::group(['middleware' => ['permission:View settings']], function () {
                Route::get('privacy_policy', 'Admin\HomeController@settings')->name('privacy_policy');
                Route::get('privacy_policy/edit', 'Admin\HomeController@editSettings')->name('editSettings');
                Route::post('privacy_policy/edit/update', 'Admin\HomeController@updateSettings');

                Route::get('/{type}', 'Admin\HomeController@settings');

                Route::group(['middleware' => ['permission:Edit settings']], function () {
                    Route::get('/{type}/edit', 'Admin\HomeController@editSettings');
                    Route::post('/{type}/edit/update', 'Admin\HomeController@updateSettings');
                });
            });

        });
    });
});
